@@ -10,7 +10,6 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import sys
 import uuid
 
 from oslo_log import log as logging
@@ -59,12 +58,7 @@ class BaseOVS(object):
         if interface_type not in [
             constants.OVS_VHOSTUSER_INTERFACE_TYPE,
             constants.OVS_VHOSTUSER_CLIENT_INTERFACE_TYPE]:
-            if sys.platform != constants.PLATFORM_WIN32:
-                # Hyper-V with OVS does not support external programming of
-                # virtual interface MTUs via netsh or other Windows tools.
-                # When plugging an interface on Windows, we therefore skip
-                # programming the MTU and fallback to DHCP advertisement.
-                linux_net.set_device_mtu(dev, mtu)
+            linux_net.set_device_mtu(dev, mtu)
         elif self._ovs_supports_mtu_requests():
             self._set_mtu_request(txn, dev, mtu)
         else:
@@ -145,7 +139,7 @@ class BaseOVS(object):
         self, bridge, dev, iface_id, mac, instance_id,
         mtu=None, interface_type=None, vhost_server_path=None,
         tag=None, pf_pci=None, vf_num=None, set_ids=True, datapath_type=None,
-        qos_type=None
+        qos_type=None, vlan_mode=None, trunks=None
     ):
         """Create OVS port
 
@@ -210,6 +204,11 @@ class BaseOVS(object):
             txn.add(self.ovsdb.add_port(bridge, dev))
             if tag:
                 txn.add(self.ovsdb.db_set('Port', dev, ('tag', tag)))
+            if vlan_mode:
+                txn.add(self.ovsdb.db_set('Port', dev,
+                                          ('vlan_mode', vlan_mode)))
+            if trunks:
+                txn.add(self.ovsdb.db_set('Port', dev, ('trunks', trunks)))
             if qid:
                 txn.add(self.ovsdb.db_set('Port', dev, ('qos', qid)))
             if col_values:
